from django import template
from csnews.models import Article

@register.inclusion_tag('news/last_news.html')
def get_last_news():
    return {'last_news': Article.objects.filter(is_public=True).order_by("-published")[:10]}



from django.db import models
from django.utils.translation import ugettext_lazy as _
from photologue.models import Photo
from django.db.models.signals import post_save
import datetime
from django.conf import settings
from django.core.mail import EmailMultiAlternatives
from django.template.loader import render_to_string

from django.shortcuts import render_to_response
from django.shortcuts import get_object_or_404
from django.template import RequestContext


class Article(models.Model):
    """Article model"""
    title  = models.CharField(_('title'), max_length=200)
    slug = models.SlugField(_('slug'),unique=True,db_index=True)
    published = models.DateTimeField(_('published'))
    summary = models.TextField(_('summary'), blank=True)
    body = models.TextField(_('body'))
    image = models.ForeignKey(Photo,null=True,blank=True,related_name=_('news image'))

    is_public = models.BooleanField(default=True)

    added = models.DateField(_('added'),auto_now_add=True)
    modified = models.DateField(_('modified'),auto_now=True)
    sent_by_email =  models.BooleanField(default=False,editable=False)

    def get_title(self):
        return self.title

    class Meta:
        verbose_name = _('article')
        verbose_name_plural = _('articles')
        ordering  = ('-published',)
        get_latest_by = 'published'


    def __unicode__(self):
        return u'%s' % self.title

    def get_absolute_url(self):
        return "/albisteak/%s" % (self.slug)
    
def send_by_email(sender, instance, created,**kwargs):
    now = datetime.datetime.now()
    send = False
    if created:
        if instance.is_public and instance.published < now:
            send = True
    else:
        if instance.is_public and instance.published < now and not(instance.sent_by_email):
            send = True

    if send:
        subject = instance.title
        message = """
        %s

        %s
        """ % (instance.summary, instance.body)
        msgf = getattr(settings,'BULETIN_EMAIL',None)
        msgt = getattr(settings,'DEFAULT_POSTA_ZERRENDA',None)
        html_msg = render_to_string('news/article_by_mail.html',{'article':instance,'STATIC_URL':getattr(settings,'STATIC_URL'),'BASE_PATH':'www.ahotsak.com'})
        msg = EmailMultiAlternatives(subject, message, msgf, [msgt])
        msg.attach_alternative(html_msg, "text/html")
        msg.send()
        instance.sent_by_email=True
        instance.save()
#post_save.connect(send_by_email, sender=Article)



from photologue.models import Photo
from urllib2 import urlopen
from django.template.defaultfilters import slugify
from django.core.files.base import ContentFile

from random import  randint

def _getUrlImage(url):
    """ """
    try:
        socket = urlopen(url)
    except:
        socket = None
    return socket 


def loadUrlImage(url='', title='', tags='', format='jpg'):
    """ """
    if not url:
        url = 'http://ahotsak.com/files/Proiektuak/beasain.jpg'
        title = 'Beasain'
        tags = 'proiektua beasain'

    slug = slugify(title)[:50]

    image = _getUrlImage(url)

    if not image:
        return 0

    if Photo.objects.filter(title_slug=slug):
        for i in range(1,1000):
            new_slug = '%s-%d' % (slug,i)
            new_title = '%s (%d)' % (title,i)
            if not Photo.objects.filter(title_slug=new_slug):
                slug = new_slug
                title = new_title
                break
        
    photo = Photo()
    photo.title = title
    photo.tags = tags
    photo.title_slug = slug
    photo.image.save('%s.%s' % (slug,format), ContentFile(image.read()))
    try:
        photo.save()
    except:
        print 'Errorea irudi honekin', photo.title
        """
        photo.title_slug = photo.title_slug + '_2'         
        photo.save()
        """
    return photo



from django.contrib import admin
from csnews.models import Article
from csnews.forms import PhotologueForeignKeyRawIdWidget
from django.conf import settings

from tinymce.widgets import TinyMCE

def show_entry_thumbnail(item):
    return item.image.admin_thumbnail()

show_entry_thumbnail.short_description = 'Argazkia'
show_entry_thumbnail.allow_tags = True

class ArticleAdmin(admin.ModelAdmin):
   
    list_display = ('id', 'title', 'published','is_public',show_entry_thumbnail)
    list_display_links = ('id','title')
    ordering = ('-id',)        
    search_fields = ['title','summary']
    prepopulated_fields = {'slug': ('title',)}
    photologue_image_fields = ('image',)
    

    class Media:
        js = (getattr(settings,'STATIC_URL','')+'tiny_mce/tiny_mce.js',
              )


class TinyMCEArticleAdmin(ArticleAdmin):
    def formfield_for_dbfield(self, db_field, **kwargs):
        if db_field.name in ('body'):
            return db_field.formfield(widget=TinyMCE(
                attrs={'cols': 80, 'rows': 30},
                mce_attrs={
                    'theme' : "advanced",
                    'mode' : "textareas",
                    'plugins': "media",
                    'extended_valid_elements' : "iframe[src|width|height|name|align]",
                    'theme_advanced_buttons1' : "formatselect,bold,italic,underline,separator,justifyleft,justifycenter,justifyright, justifyfull,bullist,numlist,undo,redo,link,unlink,image,code,removeformat",
                    'theme_advanced_buttons2' : "",
                    'theme_advanced_buttons3' : "",
                    'theme_advanced_toolbar_location' : "top",
                    'theme_advanced_toolbar_align' : "left",
                    'theme_advanced_resizing' : 'false',
                    'media_strict': 'false', 
                    },
            ))
        return super(TinyMCEArticleAdmin, self).formfield_for_dbfield(db_field, **kwargs)


admin.site.register(Article, TinyMCEArticleAdmin)



from django.shortcuts import render_to_response
from django.shortcuts import get_object_or_404
from django.template import RequestContext

from csnews.models import Article
from csnews.diggpaginator import DiggPaginator

import time
from datetime import datetime

ARTICLE_NUMBER_PER_PAGE = 20

def _get_page(list,page):
    """ """
    paginator = DiggPaginator(list, ARTICLE_NUMBER_PER_PAGE, body=5, padding=2)
    try:
        page = int(page)
    except ValueError:
        page = 1

    try:
        tor = paginator.page(page)
    except:
        tor = paginator.page(paginator.num_pages)
    return tor

def index(request):
    """ """
    h = {}
    
    h['articles'] = Article.objects.filter(is_public=True)
    h['page'] = _get_page(h['articles'],request.GET.get('orria', '1'))    
    return render_to_response('news/articles.html',h,context_instance=RequestContext(request))

def article_index(request,article_slug):
    """ """
    h = {}
    h['obj'] = get_object_or_404(Article,slug=article_slug)
    return render_to_response('news/article.html',h,context_instance=RequestContext(request))

def hemeroteka(request):
    """ """
    h = {}
    return render_to_response('news/hemeroteka.html',h,context_instance=RequestContext(request))



from django import forms
from django.contrib.admin.widgets import ForeignKeyRawIdWidget
from django.utils.html import escape
from django.utils.text import truncate_words


class PhotologueForeignKeyRawIdWidget(ForeignKeyRawIdWidget):
    """ """
    """
    def __init__(self, rel, attrs=None):
        super(PhotologueForeignKeyRawIdWidget, self).__init__(attrs)
        self.rel = rel  
    """
    def label_for_value(self, value):
        key = self.rel.get_related_field().name
        obj = self.rel.to._default_manager.get(**{key: value})
        try:
            img_url = obj.get_display_url()
        except:
            return '<br /><strong>%s</strong> ' % ('No display size defined')
        return '<br /><img src="%s" /> <br /><strong>%s</strong> ' % (img_url,escape(truncate_words(obj, 14)))        


from django.contrib.syndication.views import Feed
from csnews.models import Article

class LatestNews(Feed):
    title = 'Albisteak'
    link = '/albisteak/'
    description = 'Albisteak'
    
    title_template = 'feeds/rss_title.html'
    description_template = 'feeds/rss_description.html'

    def items(self):
        return Article.objects.filter(is_public=True).order_by('-published')[:20]

    def item_pubdate(self,item):
        return item.published
        
    def item_link(self,item):
        return u'/albisteak/%s?utm_source=rss_link&utm_medium=rss&utm_campaign=rss_feed' % (item.slug)
